import { AlterColumnNode } from '../operation-node/alter-column-node.js';
import { OperationNodeSource } from '../operation-node/operation-node-source.js';
import { DataTypeExpression } from '../parser/data-type-parser.js';
import { DefaultValueExpression } from '../parser/default-value-parser.js';
export declare class AlterColumnBuilder {
    protected readonly alterColumnNode: AlterColumnNode;
    constructor(alterColumnNode: AlterColumnNode);
    setDataType(dataType: DataTypeExpression): AlteredColumnBuilder;
    setDefault(value: DefaultValueExpression): AlteredColumnBuilder;
    dropDefault(): AlteredColumnBuilder;
    setNotNull(): AlteredColumnBuilder;
    dropNotNull(): AlteredColumnBuilder;
    /**
     * Simply calls the provided function passing `this` as the only argument. `$call` returns
     * what the provided function returns.
     */
    $call<T>(func: (qb: this) => T): T;
}
/**
 * Allows us to force consumers to do something, anything, when altering a column.
 *
 * Basically, deny the following:
 *
 * ```ts
 * db.schema.alterTable('person').alterColumn('age', (ac) => ac)
 * ```
 *
 * Which would now throw a compilation error, instead of a runtime error.
 */
export declare class AlteredColumnBuilder extends AlterColumnBuilder implements OperationNodeSource {
    toOperationNode(): AlterColumnNode;
}
export declare type AlterColumnBuilderCallback = (builder: AlterColumnBuilder) => AlteredColumnBuilder;
